Stan Math Library: stan/math/prim/scal/meta/contains_vector.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

contains_vector.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_CONTAINS_VECTOR_HPP
2 #define STAN_MATH_PRIM_SCAL_META_CONTAINS_VECTOR_HPP
3
4 #include <stan/math/prim/scal/meta/is_vector.hpp>
5
6 namespace stan {
7
8 template <typename T1,
9 typename T2 = double,
10 typename T3 = double,
11 typename T4 = double,
12 typename T5 = double,
13 typename T6 = double>
14 struct contains_vector {
15 enum {
16 value = is_vector<T1>::value
17 || is_vector<T2>::value
18 || is_vector<T3>::value
19 || is_vector<T4>::value
20 || is_vector<T5>::value
21 || is_vector<T6>::value
22 };
23 };
24
25 }
26 #endif
27
stan
Definition: log_sum_exp.hpp:8
stan::contains_vector::value
Definition: contains_vector.hpp:16
is_vector.hpp
stan::is_vector
Definition: is_vector.hpp:10
stan::contains_vector
Definition: contains_vector.hpp:14

[ Stan Home Page ] © 2011–2016, Stan Development Team.